C######################################################################

      PROGRAM MKMOD
C----------------------------------------------------------------------
C Test program that calls the ROOTS routine.
C
C Main program's fixed parameters:
C	NN	Number of layers/timescales.
C
C Main program's local variables:
C
C	RCA	Vec of reduced IRF amplitudes.
C	RCT	Vec of reduced IRF time constants.
C	HL1ST	vec of layer thicknesses.
C	ETA1ST	Vec of diffusion coefficients.
C
C
C Copyright
C ---------
C (C) 2001 K.G.Hooss
C
C This program is free software; you can redistribute it and/or
C modify it under the terms of the GNU General Public License
C as published by the Free Software Foundation; either version 2
C of the License, or (at your option) any later version.
C 
C This program is distributed in the hope that it will be useful,
C but WITHOUT ANY WARRANTY; without even the implied warranty of
C MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C GNU General Public License for more details.
C 
C You should have received a copy of the GNU General Public License
C along with this program; if not, write to the Free Software
C Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
C----------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER K, NN
      PARAMETER(NN = 4)

      REAL*8 RCT(NN), RCA(NN)
      REAL*8 HL(NN), ETA(NN)

C======================================================================
C Inititialize input variables.
C======================================================================

C----------------------------------------------------------------------
C Time constants and corresponding coefficients of the (reduced)
C combilayer IRF.
C The order is according to the time constants, the 1st of which is
C 17.6 y and the last is infinity.
C----------------------------------------------------------------------

      RCA(1) = 0.1059
      RCA(2) = 0.1103
      RCA(3) = 0.7074
      RCA(4) = 0.0764

      RCT(1)  =  17.6
      RCT(2)  =  71.9
      RCT(3)  = 258.5

C----------------------------------------------------------------------
C First-guess values to layer thicknesses [in m] (HLAYER)
C & diffusion coefficients [in m/y] (ETA).
C Note (1) that the first diffusion coefficient ETA(1) is not used by
C the model and will thus be ignored by the tuning routine,
C and (2) that the 1st layer thickness H(1) will remain unchanged which
C is allowed because the system is invariant under scaling of all
C parameters by a common factor,
C and (3) that the 2nd layer thickness H(2) cannot be choosen freely
C but depends on the choice of h1, h3, & h4; the value given here will
C be ignored by the tuning rougine.
C So the only relevant numbers are HL(1) (fixed), HL(3,4),
C and ETA(2,3,4).
C----------------------------------------------------------------------

      HL(1)  =  663.8
      HL(2)  =    0.0
      HL(3)  = 1600.0
      HL(4)  = 6000.0

      ETA(1) =    0.0
      ETA(2) =    5.0
      ETA(3) =    5.0
      ETA(4) =   15.0

C----------------------------------------------------------------------

      CALL ROOTS(RCA, RCT, HL, ETA)

C----------------------------------------------------------------------

      WRITE(*,*) '#'
      WRITE(*,*) '# MAIN PROGRAM: Hlayer & Eta.'
      WRITE(*,*) '#'
      WRITE(*,'(4F18.8)') (HL(K), K=1,NN)
      WRITE(*,'(4F18.8)') (ETA(K), K=1,NN)
      WRITE(*,*) '#'

C----------------------------------------------------------------------

      END

C-- Last line. --------------------------------------------------------
