C----------------------------------------------------------------------
C Carbon distribution tables of atmospheric and surface-layer carbon
C as function of their sum.
C The tables range from C1 = W0 (index 0) to C1 = W0 + NC1*DELC1
C (index NC1)
C
C	DELC1	Step width in C1 (carbon in the combined system).
C	CATAB	Table of atmospheric carbon loads.
C	CSTAB	Table of mixed layer carbon loads.
C	DCADC1	Table of dCA/dC1.
C	AFTAB	Table of nonlinear function A(c1).
C	BFTAB	Table of nonlinear function B(c1).
C	CFTAB	Table of nonlinear function D(c1).
C	NC1	Number of table entries (plus one to include C1=W0).
C	NEGC1	Number of table entries for negative C1.
C----------------------------------------------------------------------
C !! Note: SIAM eventually tries strong negative emissions during the
C optimization procedure; these can lead to considerable negative
C perturbations in the carbon budget, and thus to negative table
C indices. To prevent a segmentation fault crash, the tables have to
C be extended far into the negative regime.
C----------------------------------------------------------------------
C
C G.Hooss, MPI Me HH, feb 1998.
C----------------------------------------------------------------------

      INTEGER NC1, NEGC1
      REAL DELC1, DELCINV, D2C1INV, HH0
      PARAMETER (NC1     = 1000)
      PARAMETER (NEGC1   =   10)
      PARAMETER (DELC1   =  20.0)
      PARAMETER (DELCINV = 1.0 / DELC1)
      PARAMETER (D2C1INV = 0.5 / DELC1)
      PARAMETER (HH0   =   5.000E-9)

      COMMON /CTAB/HHTAB, PCTAB,
     .             CATAB, CSTAB, DCADC1, AFTAB, BFTAB, DFTAB

      REAL HHTAB(-(10*NC1):NC1), PCTAB(-(10*NC1):NC1),
     .       CATAB(-(10*NC1):NC1), CSTAB(-(10*NC1):NC1),
     .       DCADC1(-(10*NC1):NC1), AFTAB(-(10*NC1):NC1),
     .       BFTAB(-(10*NC1):NC1), DFTAB(-(10*NC1):NC1)

C----------------------------------------------------------------------
