C======================================================================
C
C spartime.h
C
C NICCS & SIAM parameters: time.
C
C======================================================================
C overall simulation time parameters
C
C	TAU	Length of economic time horizon.
C	DT	Time step in years.
C----------------------------------------------------------------------

      REAL TAU, DT
      PARAMETER (TAU  =  850.0)
      PARAMETER (DT   =    5.0)

C----------------------------------------------------------------------
C spinup parameters
C
C spinup: historical fossil-fuel CO2 emissions,
C  approximated by exponential growth.
C
C	TW	e-folding time of spinup's expon growth.
C	TSSP	start year of spinup period.
C		 This is not used in the simulation
C		 but added as an offset to the time variables
C		 before output for plotting.
C	TSPU	Length of spinup period in years.
c	EENDSP	Emission rate at end of spinup (in GtC/yr).
C
c       some typical values:
c	year	TSSP	TSPU	TW	EENDSP
c	1900	1800	190	35.0	5.46
c	1995	1800	195	35.0	6.30
c	2000	1800	200	35.0	7.09
C----------------------------------------------------------------------

      REAL TSSP, TSPU, TW, EENDSP

      PARAMETER (TSSP =    0.0)
c      PARAMETER (TSSP = 1800.0)

      PARAMETER (TSPU =  200.0)

      PARAMETER (TW     =  35.0)

c      PARAMETER (EENDSP =   6.30)
c      PARAMETER (EENDSP =   6.14)
      PARAMETER (EENDSP =   7.09)

C----------------------------------------------------------------------
C SIAM 1997 optimization parameters
C
C	TAUE	 That part of the simulation time
C		 beyond which emissions are kept constant
C		 in the SIAM 1997 optimization.
C----------------------------------------------------------------------

      REAL TAUE
      PARAMETER (TAUE = 1000.0)

C----------------------------------------------------------------------
C Integers.
C
C	NTAU	Number of time step intervals; at the same time used
C		 as upper bound for data arrays & loops. Since the lower
C		 bound is 0, the number of data points in the arrays
C		 is NTAU+1.
C
C	NTSPU	Number of time steps for spinup time (past to present).
C
C	NTAUE	Number of time steps up to the time
C		 from where the emission rate is kept constant
C		 in the SIAM 1997 optimization.
C
C----------------------------------------------------------------------

      INTEGER NTAU
      INTEGER NTSPU
      INTEGER NTAUE

      PARAMETER (NTAU   = INT (TAU   / DT))
      PARAMETER (NTSPU  = INT (TSPU  / DT))
      PARAMETER (NTAUE  = INT (TAUE  / DT))

C======================================================================
C G.Hooss, MPI Me HH, 97-01-09, 2001-09-05
C changes:
C 010906 thu	put scenario parameters out of spartime.h
C		 and into scenario generating program semis.F
C======================================================================
