
      PROGRAM SEMIS
C======================================================================
C Compute CO2 emission scenarios.
C
C
C Copyright
C ---------
C (C) 2001 K.G.Hooss
C
C This program is free software; you can redistribute it and/or
C modify it under the terms of the GNU General Public License
C as published by the Free Software Foundation; either version 2
C of the License, or (at your option) any later version.
C 
C This program is distributed in the hope that it will be useful,
C but WITHOUT ANY WARRANTY; without even the implied warranty of
C MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C GNU General Public License for more details.
C 
C You should have received a copy of the GNU General Public License
C along with this program; if not, write to the Free Software
C Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
C======================================================================

      IMPLICIT NONE

#include "spartime.h"

      REAL*8  T0GAU, T1GAU, FACLIN, TSIGMA, TALPHA
      INTEGER   NT1GAU

C----------------------------------------------------------------------
C Parameters for BAU scenario.
C TALPHA finetuned to give a maximum of
C   2265.000   0.400001E+02
C----------------------------------------------------------------------
      PARAMETER (TALPHA =   1.7716315895E-02)
C----------------------------------------------------------------------
C Old TALPHA value used until SIAM 14.4 occ
C----------------------------------------------------------------------
c      PARAMETER (TALPHA =   1.7756E-02)
C----------------------------------------------------------------------
      PARAMETER (T0GAU  = 452.7)
      PARAMETER (T1GAU  = 300.0)
c      PARAMETER (FACLIN =   0.001)
      PARAMETER (TSIGMA = 154.2319)

      PARAMETER (NT1GAU = INT (T1GAU / DT))

      INTEGER J

      REAL EA(0:NTAU), EACCUM(0:NTAU), TIME(0:NTAU)
      REAL TWINV, PULSE

      DO J = 0,NTAU
        TIME(J)=(J*DT)
      END DO

C----------------------------------------------------------------------
C Simplest scenario: No emissions at all.
C----------------------------------------------------------------------
c
c      DO J = 0, NTAU
c        EA(J) = 0.0
c      END DO
c
C----------------------------------------------------------------------
C Simple scenario: Delta-impulse distributed over the first half
C     time interval. NICCS will multiply this by its current W0
C     if it is followed by zero emissions in EA(1).
C----------------------------------------------------------------------
c
cc      PULSE = 0.01
cc      PULSE = 0.25
cc      PULSE = 1.00
c      PULSE = 3.00
c
c      EA(0) = PULSE * 2. / DT
c
c      DO J = 1, NTAU
c        EA(J) = 0.0
c      END DO
c
C----------------------------------------------------------------------
C Simple scenario: Delta-impulse in year 1995.
C----------------------------------------------------------------------
c
c      PULSE =    1.0
c      PULSE = 1000.0
c      PULSE = 5000.0
c
c      DO J = 0,NTSPU-1
c        EA(J) = 0.0
c      END DO
c
c      EA(NTSPU) = PULSE / DT
c
c      DO J = NTSPU+1, NTAU
c        EA(J) = 0.0
c      END DO
c
C-----==============---------------------------------------------------
C Spinup period: exponential growth until present time (index NTSPU).
C-----==============---------------------------------------------------

      TWINV = 1.0 / TW
      EA(0) = EENDSP * EXP((TIME(0)-TIME(NTSPU))*TWINV)
      EACCUM(0) = 0.0

      DO J = 1,NTSPU
        EA(J) = EENDSP * EXP((TIME(J)-TIME(NTSPU))*TWINV)
        EACCUM(J) = EACCUM(J-1) + EA(J)*DT
      END DO

C----------------------------------------------------------------------
C A
C Original SIAM reference scenario SA:
C   linear growth from index (NTSPU) to (NTLIN+NTSPU), then
C   constant emissions from index (NTLIN+NTSPU) to end (NTAU).
C----------------------------------------------------------------------
c
c      DO J = NTSPU+1,(NTLIN+NTSPU)
c        EA(J) = EENDSP * (1.+0.025*(TIME(J)-TIME(NTSPU)))
c      END DO
c
c      DO J = (NTLIN+NTSPU+1),NTAU
c        EA(J) =EA(NTLIN+NTSPU)
c      END DO
c
C----------------------------------------------------------------------
C BAU
C   Modified siam reference scenario
C   linear growth from index (NTSPU+1) to NT1GAU, then
C   quasi-Gauss from index NT1GAU to end (NTAU).
C----------------------------------------------------------------------

      DO J = NTSPU+1, NT1GAU
c        EA(J) = EENDSP * (1.+FACLIN*(TIME(J)-TIME(NTSPU)))
        EA(J) = EENDSP * (1.+.0221*(TIME(J)-TIME(NTSPU)))
        EACCUM(J) = EACCUM(J-1) + EA(J) * DT
      END DO

      DO J = (NT1GAU+1), NTAU
        EA(J) = TALPHA * (TIME(J)+TSSP)
     .          * EXP(-(TIME(J)-T0GAU)*(TIME(J)-T0GAU)
     .          / (2.0*TSIGMA*TSIGMA))
        EACCUM(J) = EACCUM(J-1) + EA(J) * DT
      END DO

C----------------------------------------------------------------------
C FRE
C Emissions frozen at 1990 level from index (NTSPU+1) to NT1GAU.
C Make sure that time parameters are set to SIAM values in spartime.h.
C----------------------------------------------------------------------
c
c      DO J = NTSPU+1, NTAU
c        EA(J) = EA(NTSPU-1)
c      END DO
c
C----------------------------------------------------------------------
C INPUT
C Read scenario from file.
C Insert appropriate filename in place of 'emis.deke'.
C----------------------------------------------------------------------
c
c      OPEN(30, FILE='emis.deke')
c      DO J = NTSPU, NTAU
c         READ(30,*) IDUM, DUMMY, EA(J)
c         WRITE(*,*) IDUM, DUMMY, EA(J)
c      END DO
c      WRITE(*,*) 'DUMMY = ', DUMMY
c      WRITE(*,*) 'NTAU*DT+TSSP = ', NTAU*DT+TSSP
c      CLOSE(30)
c
C======================================================================
C Output.
C======================================================================

       WRITE(*,'(A1,I5,A4,2A15)') '#', NTAU+1, '   T', 'EMIS', 'EACCUM'

       DO J=0,NTAU
         WRITE(*,'(F10.3,2E15.6)') TSSP+TIME(J), EA(J), EACCUM(J)
       END DO

       END

C== end ===============================================================
